#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://lgames.sourceforge.net/index.php?project=Barrage
# source           : http://prdownloads.sourceforge.net/lgames/barrage-1.0.2.tar.gz?download

# Package name
NAME="barrage"
# Package version
VERSION="1.0.2"
# Source code URL
SOURCE="http://prdownloads.sourceforge.net/lgames/barrage-$VERSION.tar.gz?download"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Docs
DOCS="AUTHORS BUGS COPYING ChangeLog INSTALL NEWS README TODO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Barrage is a rather violent action game
$NAME:
$NAME: The game's objective is to kill and destroy as many targets as
$NAME: possible within 3 minutes. You control a gun that may either fire
$NAME: small or large grenades at soldiers, jeeps and tanks. Targets are
$NAME: fast paced and require careful aiming as it takes half a second to
$NAME: reload the gun. Additionally you have to keep an eye on your ammo
$NAME: and reload in time. Useful to kill some minutes of idle time.
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/barrage/barrage.png
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Fix the desktop entry
sed -i -e 's/X-Red-Hat-Base;//' $PKG/usr/share/applications/$NAME.desktop
cat >> $PKG/usr/share/applications/$NAME.desktop <<EOF
Icon=barrage
EOF

# Place the icon in the right dir
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps/
cp $CWD/barrage.png $PKG/usr/share/icons/hicolor/48x48/apps/

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
